@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,13 +25,7 @@
 #include <QObject>
 #include <KContacts/Addressee>
 
-namespace Grantlee
-{
-class Engine;
-}
-
-namespace KAddressBookGrantlee
-{
+namespace KAddressBookGrantlee {
 class KADDRESSBOOK_GRANTLEE_EXPORT GrantleePrint : public PimCommon::GenericGrantleeFormatter
 {
     Q_OBJECT
@@ -40,7 +34,7 @@ public:
     explicit GrantleePrint(const QString &themePath, QObject *parent = nullptr);
     ~GrantleePrint();
 
-    QString contactsToHtml(const KContacts::Addressee::List &contacts);
+    Q_REQUIRED_RESULT QString contactsToHtml(const KContacts::Addressee::List &contacts);
 };
 }
 #endif // GRANTLEEPRINT_H
